@@ -5,6 +5,8 @@ from rich.text import Text
 
 from textual.content import Content, Span
 from textual.style import Style
+from textual.visual import RenderOptions
+from textual.widget import Widget
 
 
 def test_blank():
@@ -229,6 +231,7 @@ def test_assemble():
         ("\\[/foo", "[/foo"),
         ("\\[/foo]", "[/foo]"),
         ("\\[]", "[]"),
+        ("\\[0]", "[0]"),
     ],
 )
 def test_escape(markup: str, plain: str) -> None:
@@ -275,12 +278,11 @@ def test_first_line():
     assert first_line.spans == [Span(0, 3, "red")]
 
 
-def test_errors():
-    with pytest.raises(Exception):
-        Content.from_markup("[")
+def test_split_and_tabs():
+    spans = [
+        Span(0, 49, style="$text"),
+    ]
 
-    with pytest.raises(Exception):
-        Content.from_markup("[:")
-
-    with pytest.raises(Exception):
-        Content.from_markup("[foo")
+    content = Content("--- hello.py\t2024-01-15 10:30:00.000000000 -0800", spans=spans)
+    widget = Widget()
+    content.render_strips(0, None, Style(), RenderOptions(widget._get_style, {}))
